@@ -111,8 +111,8 @@ class Unity3D(umake.frameworks.baseinstaller.BaseInstaller):
     def __init__(self, category):
         super().__init__(name="Unity3d", description=_("Unity 3D Editor Linux experimental support"),
                          category=category, only_on_archs=['amd64'],
-                         download_page="http://forum.unity3d.com/threads/" +
-                                       "unity-on-linux-release-notes-and-known-issues.350256/",
+                         download_page="https://community.unity.com/t5/" +
+                                       "Linux-Editor/Unity-on-Linux-Release-Notes-and-Known-Issues/m-p/2323665",
                          match_last_link=True,
                          checksum_type=ChecksumType.sha1,
                          dir_to_decompress_in_tarball='unity-editor*',
@@ -138,11 +138,11 @@ class Unity3D(umake.frameworks.baseinstaller.BaseInstaller):
         url, sha1 = (None, None)
         if ".sh" in line:
             in_download = True
-            p = re.search(r'href="(.*.sh)" target', line)
+            p = re.search(r'.deb.*.href="(.*.sh)"', line)
             with suppress(AttributeError):
                 url = p.group(1)
-        if in_download is True and ')<br />' in line:
-            p = re.search(r'(\w+)\)', line)
+        if in_download is True:
+            p = re.search(r'sha1sum (\w+)\)<BR /><BR />Torrent', line)
             with suppress(AttributeError):
                 sha1 = p.group(1)
         return ((url, sha1), in_download)
@@ -221,7 +221,7 @@ class Superpowers(umake.frameworks.baseinstaller.BaseInstaller):
     def __init__(self, category):
         super().__init__(name="Superpowers", description=_("The HTML5 2D+3D game maker"),
                          category=category, only_on_archs=['i386', 'amd64'],
-                         download_page="https://api.github.com/repos/superpowers/superpowers-core/releases/latest",
+                         download_page="https://api.github.com/repos/superpowers/superpowers-app/releases/latest",
                          dir_to_decompress_in_tarball='superpowers*',
                          desktop_filename="superpowers.desktop",
                          required_files_path=["Superpowers"])
@@ -242,9 +242,12 @@ class Superpowers(umake.frameworks.baseinstaller.BaseInstaller):
 
         try:
             assets = json.loads(page.buffer.read().decode())["assets"]
+            download_url = None
             for asset in assets:
                 if "linux-{}".format(self.arch_trans[get_current_arch()]) in asset["browser_download_url"]:
                     download_url = asset["browser_download_url"]
+            if not download_url:
+                raise IndexError
         except (json.JSONDecodeError, IndexError):
             logger.error("Can't parse the download URL from the download page.")
             UI.return_main_screen(status_code=1)
@@ -256,8 +259,8 @@ class Superpowers(umake.frameworks.baseinstaller.BaseInstaller):
     def post_install(self):
         """Create the Superpowers launcher"""
         create_launcher(self.desktop_filename, get_application_desktop_file(name=_("Superpowers"),
-                        icon_path=os.path.join(self.install_path, "resources", "app", "launcher", "public", "images",
-                                               "icon.png"),
+                        icon_path=os.path.join(self.install_path, "resources", "app", "renderer",
+                                               "images", "superpowers-256.png"),
                         exec='"{}" %f'.format(self.exec_path),
                         comment=self.description,
                         categories="Development;IDE;"))
